@@ -1211,6 +1211,19 @@ g_system_thread_get_scheduler_settings (GThreadSchedulerSettings *scheduler_sett
     }
   while (res == -1);
 
+  /* Try setting them on the current thread to see if any system policies are
+   * in place that would disallow doing so */
+  res = syscall (SYS_sched_setattr, tid, scheduler_settings->attr, flags);
+  if (res == -1)
+    {
+      int errsv = errno;
+
+      g_debug ("Failed to set thread scheduler attributes: %s", g_strerror (errsv));
+      g_free (scheduler_settings->attr);
+
+      return FALSE;
+    }
+
   return TRUE;
 #else
   return FALSE;
@@ -1222,6 +1235,7 @@ static void *
 linux_pthread_proxy (void *data)
 {
   GThreadPosix *thread = data;
+  static gboolean printed_scheduler_warning = FALSE;  /* (atomic) */
 
   /* Set scheduler settings first if requested */
   if (thread->scheduler_settings)
@@ -1234,8 +1248,11 @@ linux_pthread_proxy (void *data)
       tid = (pid_t) syscall (SYS_gettid);
       res = syscall (SYS_sched_setattr, tid, thread->scheduler_settings->attr, flags);
       errsv = errno;
-      if (res == -1)
-        g_error ("Failed to set scheduler settings: %s", g_strerror (errsv));
+      if (res == -1 && g_atomic_int_compare_and_exchange (&printed_scheduler_warning, FALSE, TRUE))
+        g_critical ("Failed to set scheduler settings: %s", g_strerror (errsv));
+      else if (res == -1)
+        g_debug ("Failed to set scheduler settings: %s", g_strerror (errsv));
+      printed_scheduler_warning = TRUE;
     }
 
   return thread->proxy (data);
